

.. _http://stsci.edu/schemas/gwcs/composite_frame-1.0.0:

composite_frame-1.0.0: Represents a set of frames.
==================================================

:soft:`Type:` object.

Represents a set of frames.




